
local MakePlayerCharacter = require "prefabs/player_common"


local assets = {
    Asset("SCRIPT", "scripts/prefabs/player_common.lua"),	
	
}
local prefabs = {}

-- Custom starting items
local start_inv = {

	"greengem",	"greengem",
	"hat_hatty",
	"cane",
}

-- When the character is revived from human
local function onbecamehuman(inst)
	
	-- Set speed when loading or reviving from ghost (optional)
	inst.components.locomotor.walkspeed = 5
	inst.components.locomotor.runspeed = 7
	
	inst.Light:SetFalloff(1)
    inst.Light:SetIntensity(0.2)
    inst.Light:SetRadius(1)
    inst.Light:SetColour(97/255, 146/255, 17/255)
    inst.Light:Enable(false)
	
	inst.components.talker:Say("When Life Gives You Potatos, You Make Potato Salad!")
	
end

-- When loading or spawning the character
local function onload(inst)
    inst:ListenForEvent("ms_respawnedfromghost", onbecamehuman)
	
	if not inst:HasTag("playerghost") then
		onbecamehuman(inst)
    end
	
end

local function rangedattack(inst,data)

	local equip = inst.components.inventory:GetEquippedItem(EQUIPSLOTS.HANDS)
	local dmg = 17
	local projectile = nil
	
	if not inst.sg:HasStateTag("attack") or not data.target then 
		return 
	end
	
	if data.target:HasTag("bird") and data.target.sg:HasStateTag("flying") then
		return
	end
	
	if data.target.prefab == "buzzard" and data.target.sg:HasStateTag("flying") then
		return
	end
	
	if data.target.prefab == "mole" and data.target.isunder then
		return
	end
	
	if data.target.prefab == "birchnutdrake" and data.target.sg:HasStateTag("exit") then
		return
	end
	
	if equip and equip.components and not equip.components.projectile then
		projectile = SpawnPrefab("spit")
	
		if not projectile.components.weapon then
			projectile:AddComponent("weapon")
		end 
	
		if equip and equip.components and equip.components.weapon then
			dmg = equip.components.weapon.damage
			if dmg >= 17 then
				dmg = math.ceil(((equip.components.weapon.damage - 17)*0.5)+17)
			end
			projectile.components.weapon:SetDamage(dmg)
		end
	
		projectile.Transform:SetPosition(inst.Transform:GetWorldPosition())
		projectile.components.projectile:Throw(inst, data.target)
	
		if equip and equip.components and equip.components.finiteuses then
			equip.components.finiteuses:Use()
		end
		
	else if not equip then
		projectile = SpawnPrefab("spit")
	
		if not projectile.components.weapon then
			projectile:AddComponent("weapon")
		end 
		
		projectile.components.weapon:SetDamage(dmg)
		projectile.Transform:SetPosition(inst.Transform:GetWorldPosition())
		projectile.components.projectile:Throw(inst, data.target)
		end
	end
	
end

-- This initializes for both the server and client. Tags can be added here.
local common_postinit = function(inst) 
	-- Minimap icon
	inst.MiniMapEntity:SetIcon( "esctemplate.tex" )
end

-- This initializes for the server only. Components are added here.
local master_postinit = function(inst)
	-- choose which sounds this character will play
	inst.soundsname = "webber"
	
	-- Uncomment if "wathgrithr"(Wigfrid) or "webber" voice is used
    inst.talker_path_override = "dontstarve_DLC001/characters/"
	
	-- Stats	
	inst.components.health:SetMaxHealth(75)
	inst.components.hunger:SetMax(175)
	inst.components.sanity:SetMax(120)
	
	inst.components.locomotor.walkspeed = 5
	inst.components.locomotor.runspeed = 7
	
	-- Damage multiplier (optional)
    inst.components.combat.damagemultiplier = 2
	inst.components.combat:SetAttackPeriod(.25)
	inst.components.combat:SetDefaultDamage(10)
	inst.components.combat:SetRange(12, 2)
	inst.components.combat:SetAreaDamage(5, 1)
	
	-- Hunger rate (optional)
	inst:ListenForEvent("onmissother", rangedattack)
	
	inst.components.hunger.hungerrate = 1 * TUNING.WILSON_HUNGER_RATE
	
	inst.OnLoad = onload
    inst.OnNewSpawn = onload
	
	--science bonus
	inst.components.builder.science_bonus = 1
	
	--heal regen
	inst.components.health:StartRegen(1, 1)
	
end

return MakePlayerCharacter("esctemplate", prefabs, assets, common_postinit, master_postinit, start_inv)
